#include "osapi.h"
#include "user_interface.h"
#include "wifi.h"


const char *WiFiMode[] =
{
		"NULL",		// 0x00
		"STATION",	// 0x01
		"SOFTAP", 	// 0x02
		"STATIONAP"	// 0x03
};

void ICACHE_FLASH_ATTR setup_wifi_ap_mode(void)
{
#if 0
	wifi_set_opmode((wifi_get_opmode()|SOFTAP_MODE)&STATIONAP_MODE);
#else
    wifi_set_opmode(SOFTAP_MODE);
#endif
	struct softap_config apconfig;
	if(wifi_softap_get_config(&apconfig))
	{
		wifi_softap_dhcps_stop();
		char macaddr[6];
		wifi_get_macaddr(SOFTAP_IF, macaddr);
		os_memset(apconfig.ssid, 0, sizeof(apconfig.ssid));
		os_memset(apconfig.password, 0, sizeof(apconfig.password));
		apconfig.ssid_len = os_sprintf(apconfig.ssid, "AUDIO_%02x%02x%02x%02x%02x%02x", MAC2STR(macaddr));
		os_sprintf(apconfig.password, "%02x%02x%02x%02x%02x%02x", MAC2STR(macaddr));
		apconfig.authmode = AUTH_WPA_WPA2_PSK;
		apconfig.ssid_hidden = 0;
		apconfig.channel = 7;
		apconfig.max_connection = 10;
		if(!wifi_softap_set_config(&apconfig))
		{
			ets_uart_printf("not set AP config!\r\n");
		}
		struct ip_info ipinfo;
		if(wifi_get_ip_info(SOFTAP_IF, &ipinfo))
		{
			IP4_ADDR(&ipinfo.ip, 192, 168, 4, 1);
			IP4_ADDR(&ipinfo.gw, 192, 168, 4, 1);
			IP4_ADDR(&ipinfo.netmask, 255, 255, 255, 0);
			if(!wifi_set_ip_info(SOFTAP_IF, &ipinfo))
			{
				ets_uart_printf("not set IP config!\r\n");
			} else {
				ets_uart_printf("CONFIGURATION WEB SERVER IP: " IPSTR "\r\n", IP2STR(&ipinfo.ip));;
			}
		}
		wifi_softap_dhcps_start();
	}
	if(wifi_get_phy_mode() != PHY_MODE_11N)
		wifi_set_phy_mode(PHY_MODE_11N);
	if(wifi_station_get_auto_connect() == 0)
		wifi_station_set_auto_connect(1);

	ets_uart_printf("AP mode configured.\n");
	if(wifi_softap_get_config(&apconfig)) {
		ets_uart_printf("AP config: SSID: %s, PASSWORD: %s, CHANNEL: %u\n", apconfig.ssid,	apconfig.password, apconfig.channel);
	}
}


void ICACHE_FLASH_ATTR setup_wifi_st_mode(void) {
    wifi_set_opmode(STATION_MODE);
    struct station_config stconfig;
    wifi_station_disconnect();
    wifi_station_dhcpc_stop();
    if(wifi_station_get_config(&stconfig)) {
        os_memset(stconfig.ssid, 0, sizeof(stconfig.ssid));
        os_memset(stconfig.password, 0, sizeof(stconfig.password));
        os_sprintf(stconfig.ssid, "%s", WIFI_CLIENTSSID);
        os_sprintf(stconfig.password, "%s", WIFI_CLIENTPASSWORD);
        if(!wifi_station_set_config(&stconfig)) {
            os_printf("ESP8266 not set station config!\r\n");
        }
    }
    wifi_station_connect();
    wifi_station_dhcpc_start();
    wifi_station_set_auto_connect(1);
    os_printf("ESP8266 in STA mode configured.\r\n");
}
